@@ -1,7 +1,9 @@
 """
+# Will you ever read me?
+
 .. include:: ../README.md
-   :start-after: ![](docs/resources/logo.png)
-   :end-before: # Documentation
+   :start-after: logo.png)
+   :end-before: ## Further reading
 
 <br>
 
@@ -13,6 +15,12 @@
 
 
 import sys
+import pkg_resources
+
+try:
+    PAROXYTHON_VERSION = pkg_resources.get_distribution("paroxython").version
+except pkg_resources.DistributionNotFound:
+    PAROXYTHON_VERSION = "(unknown version)"  # For tests during CI
 
 if "ipykernel" in sys.modules:
     # Declare the magic stuff paroxython iff the module is loaded as an IPython extension.
@@ -20,10 +28,11 @@ if "ipykernel" in sys.modules:
     from IPython.core.magic import Magics, line_cell_magic, magics_class  # type: ignore
     from IPython.display import Markdown, display  # type: ignore
 
-    from paroxython.cli.cli_tag import main
+    from .cli.cli_tag import main
 
     def load_ipython_extension(ipython):
         ipython.register_magics(ParoxythonMagics)
+        print(f"Paroxython {PAROXYTHON_VERSION} loaded.")
 
     @magics_class
     class ParoxythonMagics(Magics):
