@@ -1,10 +1,10 @@
 r"""Assess the learning cost associated with the introduction of the given programs.
 
 Each program has been previously found to implement a number of notions represented by a list of
-taxa of the form: \(\textrm{edge}_0/\textrm{edge}_1/.../\textrm{edge}_n\), _e.g._,
+taxa of the form: \(\textrm{edge}_0/\textrm{edge}_1/.../\textrm{edge}_n\), e.g.,
 `flow/loop/exit/early/break`.
 
-Furthermore, the notions already imparted may cover a certain **prefix** of such a taxon, _e.g._
+Furthermore, the notions already imparted may cover a certain **prefix** of such a taxon, e.g.
 `flow/loop`. The learning cost should therefore not take it into account.
 
 The cost of the remaining edges, here `exit/early/break`, is approximated by a function taking
@@ -17,7 +17,7 @@ two zero-based indexes `start` (inclusive) and `stop` (exclusive), and returning
 
 from functools import lru_cache
 
-from paroxython.user_types import (
+from .user_types import (
     AssessedPrograms,
     AssessmentStrategy,
     ProgramInfos,
