@@ -1,7 +1,7 @@
 """Evolve a set of selected programs and a set of taxa representing the imparted knowledge.
 
 Description:
-    Initially, all programs in the database are selected, and the imparted knowledge is empty.
+    Initially, all programs in the tag database are selected, and the imparted knowledge is empty.
 
     ..note::
         As the filter evolves, the former set can only shrink, and the latter only increase.
@@ -23,9 +23,9 @@ from typing import Counter, Dict, Iterator, List, Tuple
 
 import regex  # type: ignore
 
-from paroxython.goodies import print_warning
-from paroxython.normalize_predicate import normalize_predicate
-from paroxython.user_types import (
+from .goodies import print_warning
+from .normalize_predicate import normalize_predicate
+from .user_types import (
     Criterion,
     JsonDatabase,
     Operation,
@@ -57,7 +57,7 @@ class ProgramFilter:
         self.add_imported_taxa()
 
     def define_shortcuts(self, db: JsonDatabase) -> None:
-        """Define some attributes that point directly to the main parts of the database."""
+        """Define some attributes that point directly to the main parts of the tag database."""
         self.db_programs: ProgramInfos = db["programs"]
         self.db_taxa: TaxonInfos = db["taxa"]
         self.db_importations: ProgramToPrograms = db["importations"]
@@ -74,7 +74,7 @@ class ProgramFilter:
         """Copy under each program the taxa it featured by importation.
 
         Description:
-            Initially, the JSON database stores under each program all the taxa it features
+            Initially, the JSON tag database stores under each program all the taxa it features
             _directly_, for instance:
             ```
             {
@@ -227,7 +227,7 @@ class ProgramFilter:
                     are excluded too.
 
         Args:
-            criteria (List[Criterion]): A list of criteria, _i.e._, a mix of regular expression
+            criteria (List[Criterion]): A list of criteria, i.e., a mix of regular expression
                 patterns (strings) and/or predicates (triples).
             operation (Operation): Either `"impart"`, `"hide"`, `"include"` or `"exclude"`.
             quantifier (str): Either `"any"` or `"all"`.
@@ -299,7 +299,7 @@ class ProgramFilter:
                 `ProgramFilter.programs_of_negated_triple`.
 
         Args:
-            criteria (List[Criterion]): A list of criteria, _i.e._, a mix of regular expression
+            criteria (List[Criterion]): A list of criteria, i.e., a mix of regular expression
                 patterns (strings) and/or predicates (triples).
             follow (bool): If `True`, extend the result with all the programs which import (either
                 directly or by transitivity) at least one program meeting a criterion.
@@ -483,7 +483,7 @@ class ProgramFilter:
 
             Suppose first that the sets `taxa_1` and `taxa_2` have no common taxa. In this
             case, the couples of spans on which to check the predicate are obtained by a simple
-            cross-product, _e.g._:
+            cross-product, e.g.:
 
             >>> iterate_on_spans(spans, {"t1", "t2"}, {"t3", "t4"})
             ((1, 1), (3, 3))  # t1 (1) ⨉ t3
