@@ -9,9 +9,9 @@ from typing import Callable, Dict, List, Iterator, Tuple
 
 import regex  # type: ignore
 
-from paroxython.derived_labels_db import DerivedLabelsDatabase
-from paroxython.flatten_ast import flatten_ast
-from paroxython.user_types import (
+from .derived_labels_db import DerivedLabelsDatabase
+from .flatten_ast import flatten_ast
+from .user_types import (
     Label,
     LabelName,
     Labels,
@@ -50,7 +50,7 @@ def find_all_features(
     Returns:
         Iterator[Tuple[LabelName, str, str]]: An iterator yielding all matching triples of the form:
 
-            1. label name pattern (_e.g._, `"try"` or `"try_raise|try_except"`),
+            1. label name pattern (e.g., `"try"` or `"try_raise|try_except"`),
             2. language (currently, `"re"` or `"sql"`),
             3. specification (respectively, a regular expression pattern or an SQL query).
     """
@@ -329,7 +329,7 @@ class ProgramParser:
 
 if __name__ == "__main__":
     # Take an individual source, print its features and write its flat AST.
-    from paroxython.goodies import couple_to_string
+    from .goodies import couple_to_string
 
     path = Path("sandbox/source.py")
     source = path.read_text().strip()
