@@ -11,8 +11,8 @@ stage, the so-called “manual hints”, presented in the next paragraph.
 ## Manual hints
 
 On a given source code, the labelling algorithm may sometimes produce false positives or false
-negatives. Moreover, the semantics of some features may be subjective (_e.g._, `topic:fun`) or beyond
-the capabilities of Paroxython (_e.g._, deciding the relevance of the `short_circuit` property of a
+negatives. Moreover, the semantics of some features may be subjective (e.g., `topic:fun`) or beyond
+the capabilities of Paroxython (e.g., deciding the relevance of the `short_circuit` property of a
 boolean condition). In any case, the user has the possibility to manually label certain lines of
 their source code to hint either the presence or absence of a given feature.
 
@@ -54,7 +54,7 @@ from typing import Callable, Dict, List, Tuple, Set
 
 import regex  # type: ignore
 
-from paroxython.user_types import LabelName, LabelsSpans, Source, Span
+from .user_types import LabelName, LabelsSpans, Source, Span
 
 HINT_COMMENT = "# paroxython:"
 
